@@ -21,6 +21,7 @@ from .._impl import (
     scout_rids_api_SnapshotRid as SnapshotRid,
     scout_rids_api_TemplateRid as TemplateRid,
     scout_rids_api_TypeRid as TypeRid,
+    scout_rids_api_UserDuration as UserDuration,
     scout_rids_api_UserRid as UserRid,
     scout_rids_api_Version as Version,
     scout_rids_api_VersionedVizId as VersionedVizId,
@@ -49,6 +50,7 @@ __all__ = [
     'SnapshotRid',
     'TemplateRid',
     'TypeRid',
+    'UserDuration',
     'UserRid',
     'Version',
     'VersionedVizId',
