@@ -5,3 +5,9 @@ from .._impl import (
     storage_deletion_api_TimeRange as TimeRange,
 )
 
+__all__ = [
+    'DeleteDataRequest',
+    'TimeRange',
+    'InternalNominalStorageDataDeletionService',
+]
+
